<?php

if ( ! function_exists( 'upv_setup' ) ) :


function upv_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Upv, use a find and replace
	 * to change 'upv' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'upv', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );
	
	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Principal', 'upv' ),
		'secondary' => esc_html__( 'Herramientas', 'upv' ),
		'footer' => esc_html__( 'Pie', 'upv' )
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	
}
endif;



add_action( 'after_setup_theme', 'upv_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function upv_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'upv_content_width', 640 );
}
add_action( 'after_setup_theme', 'upv_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function upv_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'upv' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'upv' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title"><a class="toggle">',
		'after_title'   => '</a></h4>',
	) );
}
add_action( 'widgets_init', 'upv_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function upv_scripts() {
	wp_enqueue_style( 'slider', get_template_directory_uri() . '/fonts/font-awesome/css/font-awesome.min.css',false,'1.1','all');

	wp_enqueue_style( 'upv-style', get_stylesheet_uri() );

//	wp_enqueue_script( 'upv-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	
	wp_enqueue_script( 'custom', get_template_directory_uri() . '/js/custom.js', array(), '20151215', true );

	wp_enqueue_script( 'upv-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'upv_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';


/** Add jquery **/

if (!is_admin()) add_action("wp_enqueue_scripts", "my_jquery_enqueue", 11);
function my_jquery_enqueue() {
   wp_deregister_script('jquery');
   wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js", false, null);
   wp_enqueue_script('jquery');
}


/** Custom admin options **/

// create custom plugin settings menu
add_action('admin_menu', 'my_cool_plugin_create_menu');

function my_cool_plugin_create_menu() {

	//create new top-level menu
	add_menu_page('Opciones del tema', 'Opciones del Tema', 'administrator', __FILE__, 'my_cool_plugin_settings_page' );

	//call register settings function
	add_action( 'admin_init', 'register_my_cool_plugin_settings' );
}


function register_my_cool_plugin_settings() { // Definimos las opciones
	//register our settings
	register_setting( 'my-cool-plugin-settings-group', 'new_option_home' );
	register_setting( 'my-cool-plugin-settings-group', 'new_option_page' );
	register_setting( 'my-cool-plugin-settings-group', 'new_option_post' );
	register_setting( 'my-cool-plugin-settings-group', 'date_option' );
	register_setting( 'my-cool-plugin-settings-group', 'footer_option' );
}


function my_cool_plugin_settings_page() {
	
	wp_enqueue_script('jquery');
// This will enqueue the Media Uploader script
wp_enqueue_media();
?>
<div class="wrap">
<h1>Opciones del tema</h1>

<form method="post" action="options.php"  enctype="multipart/form-data">
    <?php settings_fields( 'my-cool-plugin-settings-group' ); ?>
    <?php do_settings_sections( 'my-cool-plugin-settings-group' ); ?>
    <table class="form-table">
        <tr valign="top">
        <th scope="row">Sidebar en la home</th>
        <td><input type="checkbox" id="checkbox_home" name="new_option_home" value="1" <?php echo checked( 1, get_option( 'new_option_home' ), false );?> /></td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Sidebar en las páginas</th>
        <td><input type="checkbox" id="checkbox_page" name="new_option_page" value="1" <?php echo checked( 1, get_option( 'new_option_page' ), false );?> /></td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Sidebar en los post</th>
        <td><input type="checkbox" id="checkbox_post" name="new_option_post" value="1" <?php echo checked( 1, get_option( 'new_option_post' ), false );?> /></td>
        </tr>
        
        <tr valign="top">
        <th scope="row">Mostrar el autor en las entradas</th>
        <td><input type="checkbox" id="checkbox_post" name="date_option" value="1" <?php echo checked( 1, get_option( 'date_option' ), false );?> /></td>
        </tr>
        
         <tr valign="top">
        <th scope="row">Ocultar footer</th>
        <td><input type="checkbox" id="checkbox_footer" name="footer_option" value="1" <?php echo checked( 1, get_option( 'footer_option' ), false );?> /></td>
        </tr>
        
              
            </table>
    <div>
  
</div>
    <?php submit_button(); ?>

</form>
</div>
<?php }
